<h1 align="center">
  <img src="https://raw.githubusercontent.com/skippy-dev/skippy/main/img/skippy.png" width="200px" alt="skippy">
</h1>

<p align="center">
  <a href="https://www.python.org/"><img src="https://img.shields.io/badge/Made%20with-Python-1f425f.svg"></a>
  <a href="https://pypi.python.org/pypi/skippy-pad/"><img src="https://img.shields.io/pypi/l/skippy-pad.svg"></a>
  <a href="https://pypi.python.org/pypi/skippy-pad/"><img src="https://img.shields.io/pypi/v/skippy-pad.svg"></a>
  <a href="https://pypi.python.org/pypi/skippy-pad/"><img src="https://img.shields.io/pypi/pyversions/skippy-pad.svg"></a>
  <a href="https://github.com/psf/black"><img src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
</p>

<p align="center">
<a href="https://GitHub.com/MrNereof/"><img src="http://ForTheBadge.com/images/badges/built-with-love.svg"></a>
</p>

<h3 align="center">
Skippy - Simple. Comfortable. Powerful. notepad for www.scpwiki.com
</h3>

<h2>
Installation
</h2>

Installing Skippy with pip is easy:

```
$ pip install skippy-pad
```

<h2>
Usage
</h2>

Open console and write:

```
$ skippy
```

<h2>
Features
</h2>

* Support Python 3.4+
* Powerful functional
* Easy to use plugin system
* Support all wikidot site

<h2>
Screenshots
</h2>

<h3>
White theme
</h3>

<div align="center">
<img src="https://raw.githubusercontent.com/skippy-dev/skippy/main/img/white.png">
</div>

<h3>
Black theme
</h3>

<div align="center">
<img src="https://raw.githubusercontent.com/skippy-dev/skippy/main/img/black.png">
</div>

<h2>
Bugs/Requests
</h2>

Please use the <a href="https://github.com/skippy-dev/skippy/issues">GitHub issue tracker</a> to submit bugs or request features.

<h2>
Author
</h2>

* <a href="https://github.com/MrNereof">MrNereof</a> - owner of Skippy.
* <a href="http://www.wikidot.com/user:info/the-great-hippo">The Great Hippo</a> - original creator <a href="http://scpwiki.com/your-very-first-scp">Skippy as a character</a>.

<h2>
Donating
</h2>

* Cryptocurrencies:
  * Binance Smart Chain (BSC) - 0x581cc7acbe921b1fa9fccbbfe008c86f68bc097d (BTC, ETH, DOGE and etc.)

<h2>
License
</h2>

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see https://www.gnu.org/licenses/gpl-3.0.txt.
